Method: EventMachine::RTMP::ResponseRouter#receive_header

Defined in:
lib/em-rtmp/response_router.rb

#receive_header(header) ⇒ Object

Receive a fresh header, add it to the appropriate response and receive a chunk of data for that response.

header - Header to receive and act on

Returns nothing



37
38
39
40
41
# File 'lib/em-rtmp/response_router.rb', line 37

def receive_header(header)
  response = Response.find_or_create(header.channel_id, @connection)
  response.add_header header
  receive_chunk response
end